@@ -11,12 +11,13 @@ our @BBB     = ();
 our %CCC     = ();
 
 sub bbb     { }
-sub bbb_2fa { }
+sub bba_2fa { }
 
 our @EXPORT_OK = (
     '$AAA',
     '$AAA_2FA',
     'bbb',
+    'bba_2fa',
     '@BBB',
     '%CCC',
 );
